@@ -1,9 +1,7 @@
 from django.contrib.admin.apps import AdminConfig as DefaultAdminConfig
 
-__all__ = (
-    'AdminConfig',
-)
+__all__ = ("AdminConfig",)
 
 
 class AdminConfig(DefaultAdminConfig):
-    default_site = 'playground.config.admin.AdminSite'
+    default_site = "config.admin.AdminSite"
